@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 # ABSTRACT: Test framework for Config::Model
-$Config::Model::Tester::VERSION = '2.049';
+$Config::Model::Tester::VERSION = '2.050';
 use warnings;
 use strict;
 use locale;
@@ -236,7 +236,7 @@ sub check_data {
         my $check_v    = ref $v eq 'HASH' ? delete $v->{value} : $v;
         my @check_args = ref $v eq 'HASH' ? %$v : ();
         my $check_str  = @check_args ? " (@check_args)" : '';
-        my $obj = $root->grab( step => $path, @check_args, type => 'leaf' );
+        my $obj = $root->grab( step => $path, type => ['leaf','check_list'], @check_args );
         my $got = $obj->fetch(@check_args);
         if (ref $check_v eq 'Regexp') {
             like( $got, $check_v, "$label check '$path' value with regexp$check_str" );
@@ -490,7 +490,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 2.049
+version 2.050
 
 =head1 SYNOPSIS
 
